package com.hungraim.ism.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.hungraim.ism.pojo.vo.disable.DisableExamineInfoVO;
import com.hungraim.ism.pojo.vo.disable.DisableVO;
import com.hungraim.ltc.pojo.entity.disable.*;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 失能申请Service
 *
 * @author czz
 */
@Service
public interface DisableService {

    /**
     * 查询所有资源对应的角色
     *
     * @param organId               适用机构代码
     * @param isIncludeSubsidiaries 是否包含子机构 0包含,1不包含
     * @param districtProvincial    所在省
     * @param districtCity          所在市
     * @param districtArea          所在区域
     * @param realName              失能人员姓名
     * @param certiCode             失能人员身份证号码
     * @param dataFrom              申请来源
     * @param srvOrganId            护理机构
     * @param pageNum               当前页
     * @param pageSize              每页几条数据
     * @return list
     */
    Page<DisableVO> disableList(String organId, String isIncludeSubsidiaries, String districtProvincial, String districtCity,
                                String districtArea, String realName, String certiCode, String dataFrom,
                                String srvOrganId, int pageNum, int pageSize);

    /**
     * 失能审核信息详情
     *
     * @param applyId 申请id
     * @return 失能审核信息详情
     */
    DisableExamineInfoVO disableExamineInfo(String applyId);

    void addDisable(ChDisableApply chDisableApply);

    void disableExamine(String applyId, String checkName, Short applyStatus, String checkRemark);

    /**
     * 省市区
     *
     * @param districtLevel 区域级别:1省2地级市3县
     * @param districtCode  上级区域代码
     */
    List<ChFndDistrict> district(String districtLevel, String districtCode);

    List<ChFndOrgan> fndOrganRoot();

    /**
     * 查询所有服务方式
     */
    List<ChFndSrvMode> fndSrvModeList();

    /**
     * 查询机构下所有护理机构
     *
     * @param organId 机构id
     */
    List<ChSrvOrgan> srvOrganList(String organId);

    /**
     * 查询疾病类型
     *
     * @param parDiseTypeId 父疾病类型id
     */
    List<ChFndDiseaseType> fndDiseaseList(String parDiseTypeId);

    /**
     * 查询护理机构下所有子机构id
     *
     * @param organId 机构id
     * @return 机构及所有子机构id,以逗号分隔,如果没有子机构则只返回机构id
     */
    String subsidiariesOrganId(String organId);
}
