package com.hungraim.ltc.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.hungraim.ism.pojo.vo.disable.DisableEvaluateInfoVO;
import com.hungraim.ltc.pojo.entity.eval.ChAprTask;
import com.hungraim.ltc.pojo.vo.assessment.TaskDistributionVO;
import com.hungraim.ltc.service.TaskService;
import com.hungraim.ltc.util.Result;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 失能评定Controller
 *
 * @author czz
 */
@RestController
@RequestMapping("/api.apply/task")
@Slf4j
public class TaskController {

    @Autowired
    private TaskService taskService;

    /**
     * 评定任务分配列表
     *
     * @param organId               适用机构代码
     * @param isIncludeSubsidiaries 是否包含子机构 0包含,1不包含
     * @param provincial            所在省
     * @param city                  所在市
     * @param area                  所在区域
     * @param street                所在街道
     * @param realName              失能人员姓名
     * @param certiCode             失能人员身份证号码
     * @param taskName              评定人员姓名
     * @param taskTel               评定人员手机号码
     * @param daysRemaining         评定剩余天数
     * @param status                任务状态
     * @param isReturn              是否退回
     * @param pageNum               当前页
     * @param pageSize              每页几条数据
     */
    @RequestMapping("/taskDistributionList")
    public Result<List<TaskDistributionVO>> taskDistributionList(String organId, String isIncludeSubsidiaries, String provincial, String city,
                                                                 String street, String realName, String certiCode, String taskName, String taskTel,
                                                                 String daysRemaining, String status, String isReturn, String area,
                                                                 int pageNum, int pageSize) {
        IPage<TaskDistributionVO> iPage = taskService.taskDistributionList(organId, isIncludeSubsidiaries, provincial, city,
                street, realName, certiCode, taskName, taskTel, daysRemaining, status, isReturn, area,
                pageNum, pageSize);
        return Result.success(iPage.getRecords());
    }

    /**
     * 失能评定详情
     *
     * @param evaluateId 评定id
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableEvaluateInfo")
    public Result<DisableEvaluateInfoVO> disableEvaluateInfo(String evaluateId) {
        DisableEvaluateInfoVO disableEvaluateInfoVO = taskService.disableEvaluateInfo(evaluateId);
        return Result.success(disableEvaluateInfoVO);
    }

    /**
     * 失能评定
     *
     * @param applyId     申请id
     * @param checkName   审核人
     * @param applyStatus 审核结果
     * @param checkRemark 审核备注
     * @return 失能审核信息详情
     */
    @RequestMapping("/disableEvaluate")
    public Result disableEvaluate(String applyId, String checkName, Short applyStatus, String checkRemark) {
        return Result.success();
    }

    /**
     * 新增失能评定
     */
    @RequestMapping("/addAprTask")
    public Result addAprTask(ChAprTask chAprTask) {
        return Result.success();
    }

}
